@@ -1,6 +1,5 @@
 """Vtk legend parameters."""
 
-from _pytest.python_api import raises
 import vtk
 from ladybug.color import Colorset, Color
 from enum import Enum, auto
@@ -167,7 +166,7 @@ class Text:
     @size.setter
     def size(self, val) -> None:
         if not val:
-            self._size = 30
+            self._size = 0
         elif isinstance(val, int):
             self._size = val
         else:
@@ -273,8 +272,8 @@ class LegendParameter:
             label_count: int = None,
             decimal_count: DecimalCount = DecimalCount.default,
             preceding_labels: bool = False,
-            label_parameters: Text = Text(color=(0, 0, 0), size=30),
-            title_parameters: Text = Text(color=(0, 0, 0), size=50, bold=True),
+            label_parameters: Text = Text(color=(0, 0, 0), size=0),
+            title_parameters: Text = Text(color=(0, 0, 0), size=0, bold=True),
             min: Union[float, int] = None,
             max: Union[float, int] = None,
             auto_range: Tuple[float, float] = None) -> None:
@@ -513,7 +512,7 @@ class LegendParameter:
     @label_parameters.setter
     def label_parameters(self, val) -> None:
         if not val:
-            self._label_parameters = Text(color=(0, 0, 0), size=30)
+            self._label_parameters = Text()
         elif isinstance(val, Text):
             self._label_parameters = val
         else:
@@ -529,7 +528,7 @@ class LegendParameter:
     @title_parameters.setter
     def title_parameters(self, val) -> None:
         if not val:
-            self._title_parameters = Text(color=(0, 0, 0), size=30, bold=True)
+            self._title_parameters = Text(bold=True)
         elif isinstance(val, Text):
             self._title_parameters = val
         else:
@@ -543,7 +542,7 @@ class LegendParameter:
 
     @min.setter
     def min(self, val):
-        if not val:
+        if val == None:
             self._min = None
         elif isinstance(val, (int, float)):
             self._min = val
@@ -558,7 +557,7 @@ class LegendParameter:
 
     @max.setter
     def max(self, val):
-        if not val:
+        if val == None:
             self._max = None
         elif isinstance(val, (int, float)):
             self._max = val
@@ -586,11 +585,11 @@ class LegendParameter:
             )
 
     @property
-    def range(self):
-        if not self._min and not self._max:
+    def range(self) -> Tuple[float, float]:
+        if self._min == None and self._max == None:
             return self._auto_range
 
-        elif self._min and not self._max:
+        elif self._min and self._max == None:
             if self._min < self._auto_range[1]:
                 return (self._min, self._auto_range[1])
             else:
@@ -601,7 +600,7 @@ class LegendParameter:
                     ' provide a max value.'
                 )
 
-        elif not self._min and self._max:
+        elif self._min == None and self._max:
             if self._max > self._auto_range[0]:
                 return (self._auto_range[0], self._max)
             else:
@@ -612,7 +611,7 @@ class LegendParameter:
                     ' provide a min value.'
                 )
 
-        elif self._min and self._max:
+        elif isinstance(self._min, (int, float)) and isinstance(self._max, (int, float)):
             if self._min < self._max:
                 return (self._min, self._max)
             else:
