@@ -21,6 +21,7 @@ from ladybug_geometry.geometry3d import Face3D, Mesh3D, Point3D, Vector3D, Polyl
 from honeybee.room import Room
 from honeybee.face import Face
 from honeybee.aperture import Aperture
+from honeybee.door import Door
 from honeybee.shade import Shade
 from honeybee_radiance.sensorgrid import SensorGrid
 
@@ -79,7 +80,7 @@ def convert_mesh(mesh: Mesh3D) -> PolyData:
 
 def convert_sensor_grid(
     sensor_grid: SensorGrid, load_option: SensorGridOptions = SensorGridOptions.Mesh
-        ) -> PolyData:
+) -> PolyData:
     """Convert a honeybee-radiance sensor grid to a vtkPolyData."""
     if load_option == SensorGridOptions.Sensors:
         # load sensors
@@ -91,44 +92,54 @@ def convert_sensor_grid(
             raise ValueError(
                 f'{sensor_grid.display_name} does not include mesh information. '
                 'Try again with SensorGridOptions.Sensors'
-                )
+            )
         grid_data = convert_mesh(sensor_grid.mesh)
 
     grid_data.identifier = sensor_grid.identifier
-    grid_data.display_name = sensor_grid.display_name
+    grid_data.name = sensor_grid.display_name
     grid_data.type = 'Grid'
     return grid_data
 
 
 def convert_shade(shade: Shade) -> PolyData:
-    shade_data = convert_face_3d(shade.geometry)
-    shade_data.identifier = shade.identifier
-    shade_data.display_name = shade.display_name
-    shade_data.type = 'Shade'
-    return shade_data
+    polydata = convert_face_3d(shade.geometry)
+    metadata = polydata._get_metadata(shade)
+    polydata._add_metadata(metadata)
+    return polydata
 
 
 def convert_aperture(aperture: Aperture) -> List[PolyData]:
-    aperture_data = convert_face_3d(aperture.geometry)
-    aperture_data.type = 'Aperture'
-    aperture_data.identifier = aperture.identifier
-    aperture_data.display_name = aperture.display_name
-    data = [aperture_data]
+    polydata = convert_face_3d(aperture.geometry)
+    metadata = polydata._get_metadata(aperture)
+    polydata._add_metadata(metadata)
+    data = [polydata]
     for shade in aperture.outdoor_shades:
-        shade_data = convert_shade(shade)
-        data.append(shade_data)
+        polydata = convert_shade(shade)
+        data.append(polydata)
+    return data
+
+
+def convert_door(door: Door) -> List[PolyData]:
+    polydata = convert_face_3d(door.geometry)
+    metadata = polydata._get_metadata(door)
+    polydata._add_metadata(metadata)
+    data = [polydata]
     return data
 
 
 def convert_face(face: Face) -> List[PolyData]:
     """Convert a HBFace to a PolyData."""
+
     polydata = convert_face_3d(face.punched_geometry)
-    polydata.type = face.type.name
-    polydata.identifier = face.identifier
-    polydata.display_name = face.display_name
+    metadata = polydata._get_metadata(face)
+    polydata._add_metadata(metadata)
     data = [polydata]
-    for aperture in face.apertures:
-        data.extend(convert_aperture(aperture))
+    if face.apertures:
+        for aperture in face.apertures:
+            data.extend(convert_aperture(aperture))
+    if face.doors:
+        for door in face.doors:
+            data.extend(convert_door(door))
     return data
 
 
@@ -145,7 +156,7 @@ def convert_points(points: List[Point3D]) -> PolyData:
     """Export a list of points to VTK.
 
     Args:
-        points : A list of Point3D.
+        points: A list of Point3D.
 
     Returns:
         A vtk object with multiple VTK point objects.
@@ -198,7 +209,7 @@ def _create_lines(
 def _create_cone(
     center: Point3D, vector: Vector3D, radius: float = 0.1, height: float = 0.3,
     resolution: int = 2
-        ) -> PolyData:
+) -> PolyData:
     cone_poly = vtk.vtkPolyData()
 
     # Parameters for the cone
