@@ -11,12 +11,17 @@ https://lorensen.github.io/VTKExamples/site/Cxx/PolyData/FieldData/
 
 import pathlib
 import vtk
+import warnings
 
 from enum import Enum
 from typing import Dict, Union, List, Tuple
 from ladybug.color import Color
 from .legend_parameter import LegendParameter, ColorSets
 from .vtkjs.schema import DataSetProperty, DataSet, DisplayMode, DataSetMapper
+from honeybee.face import Face
+from honeybee.aperture import Aperture
+from honeybee.door import Door
+from honeybee.shade import Shade
 
 
 class DataSetNames(Enum):
@@ -90,6 +95,81 @@ class DataFieldInfo:
         return self._range
 
 
+def _get_data_range(
+        name: str,
+        data_range: List[Union[float, int]],
+        array: Union[vtk.vtkFloatArray, vtk.vtkIntArray]) -> List[Union[float, int]]:
+    """Calculate data range for data based on data array and user provided legend range.
+
+    Args:
+        name: Name of data (e.g. Useful Daylight Autonomy.)
+        data_range: A list of numbers.
+        array: A vtk float array or a vtk int array.
+
+    Returns:
+        A list of min and max values to be used as a range for the data.
+    """
+
+    # calculate range based on the data
+    if not isinstance(array, vtk.vtkStringArray):
+
+        auto_range = array.GetRange()
+
+        if not data_range:
+            warnings.warn(
+                f'In data {name.capitalize()}, since min and max'
+                ' values of legend are not provided, those values will be auto'
+                ' calculated based on data. \n'
+            )
+            return tuple(auto_range)
+
+        min, max = data_range
+        if min == None and max == None:
+            warnings.warn(
+                f'In data {name.capitalize()}, since min and max'
+                ' values of legend are not provided, those values will be auto'
+                ' calculated based on data. \n'
+            )
+            return tuple(auto_range)
+
+        elif min == None and max:
+            warnings.warn(
+                f'In data {name.capitalize()}, since min'
+                ' value of the legend is not provided, that value will be auto'
+                ' calculated based on data. \n'
+            )
+            return (auto_range[0], max)
+
+        elif min and max == None:
+            warnings.warn(
+                f'In data {name.capitalize()}, since max'
+                ' value of the legend is not provided, that value will be auto'
+                ' calculated based on data. \n'
+            )
+            return (min, auto_range[1])
+
+        elif min == 0 and max == 0:
+            raise ValueError(
+                f'In data {name.capitalize()}, min and max values'
+                ' of legend cannot be both 0. \n'
+            )
+
+        elif isinstance(min, (float, int)) and isinstance(max, (float, int)):
+            if min >= max:
+                raise ValueError(
+                    f'In data {name.capitalize()} Min value cannot be greater'
+                    ' than the max value.')
+            if min == max:
+                raise ValueError(
+                    f'In data {name.capitalize()} Min and max values cannot'
+                    ' be the same.')
+            else:
+                return (min, max)
+
+    else:
+        return tuple(data_range)
+
+
 class PolyData(vtk.vtkPolyData):
     """A thin wrapper around vtk.vtkPolyData.
 
@@ -99,20 +179,25 @@ class PolyData(vtk.vtkPolyData):
     def __init__(self) -> None:
         super().__init__()
         self.identifier = None
-        self.display_name = None
+        self.name = None
         self.type = None
+        self.boundary = None
+        self.construction = None
+        self.modifier = None
         self._fields = {}  # keep track of information for each data field.
 
-    @staticmethod
+    @ staticmethod
     def _resolve_array_type(data):
         if isinstance(data, float):
             return vtk.vtkFloatArray()
         elif isinstance(data, int):
             return vtk.vtkIntArray()
+        elif isinstance(data, str):
+            return vtk.vtkStringArray()
         else:
             raise ValueError(f'Unsupported input data type: {type(data)}')
 
-    @property
+    @ property
     def data_fields(self) -> Dict[str, DataFieldInfo]:
         """Get data fields for this Polydata."""
         return self._fields
@@ -165,14 +250,19 @@ class PolyData(vtk.vtkPolyData):
 
         self.Modified()
 
-        # store information
-        if not data_range:
-            data_range = tuple(values.GetRange())
+        # set data range
+        data_range = _get_data_range(name, data_range, values)
+
+        # set colors
         if not colors:
             colors = ColorSets.ecotect
 
         self._fields[name] = DataFieldInfo(name, data_range, colors, cell)
 
+        # if it's a string array don't publish the legend
+        if isinstance(values, vtk.vtkStringArray):
+            self._fields[name].legend_parameter.hide_legend = True
+
     def color_by(self, name: str, cell=True) -> None:
         """Set the name for active data that should be used to color PolyData."""
         assert name in self._fields, \
@@ -208,6 +298,78 @@ class PolyData(vtk.vtkPolyData):
         """
         return _write_to_folder(self, target_folder)
 
+    def _get_metadata(self, hb_object: Union[Face, Aperture, Shade]) -> Dict[str, list]:
+        """Extract metadata from a honeybee object and get it as a dictionary.
+
+        This private method will extract properties such as display name,
+        boundary condition, construction display name, and modifier display name from
+        a honeybee object and will return a dictionary that has property name as keys
+        and a list of property names as values. The length of the list will be
+        equal to the number of cells in the Polydata object.
+        """
+
+        # extracting metadata and setting attributes
+        if isinstance(hb_object, Face):
+            self.type = hb_object.type.name
+        elif isinstance(hb_object, Aperture):
+            self.type = 'Aperture'
+        elif isinstance(hb_object, Shade):
+            self.type = 'Shade'
+        elif isinstance(hb_object, Door):
+            self.type = 'Door'
+        self.identifier = hb_object.identifier
+        self.name = hb_object.display_name
+        if self.type != 'Shade':
+            self.boundary = hb_object.boundary_condition.ToString()
+        self.construction = hb_object.properties.energy.construction.display_name
+        self.modifier = hb_object.properties.radiance.modifier.display_name
+
+        # number of cells in polydata
+        num_of_cells = self.GetNumberOfCells()
+
+        # creating a dictionary with metadata name : List[metadata value] structure
+        if self.type == 'Shade':
+            name = [self.name] * num_of_cells
+            construction = [self.construction] * num_of_cells
+            modifier = [self.modifier] * num_of_cells
+
+            metadata = {
+                "Name": name,
+                "Construction": construction,
+                "Modifier": modifier
+            }
+        else:
+            name = [self.name] * num_of_cells
+            boundary = [self.boundary] * num_of_cells
+            construction = [self.construction] * num_of_cells
+            modifier = [self.modifier] * num_of_cells
+
+            metadata = {
+                "Name": name,
+                "Boundary": boundary,
+                "Construction": construction,
+                "Modifier": modifier
+            }
+
+        return metadata
+
+    def _add_metadata(self, metadata: Dict[str, list]) -> None:
+        """Add metadata to Polydata.
+
+        Args:
+            metadata: A dictionary generated from _get_metadata method.
+        """
+        for key, value in metadata.items():
+            self.add_data(value, key, data_range=[0, 0])
+
+    def __repr__(self) -> Tuple[str]:
+        return (
+            f'Name: {self.name} |'
+            f' Boundary: {self.boundary} |'
+            f' Construction: {self.construction} |'
+            f' Modifier: {self.modifier}'
+        )
+
 
 class JoinedPolyData(vtk.vtkAppendPolyData):
     """A thin wrapper around vtk.vtkAppendPolyData."""
@@ -215,7 +377,7 @@ class JoinedPolyData(vtk.vtkAppendPolyData):
     def __init__(self) -> None:
         super().__init__()
 
-    @classmethod
+    @ classmethod
     def from_polydata(cls, polydata: List[PolyData]):
         """Join several polygonal datasets.
 
@@ -283,11 +445,11 @@ class ModelDataSet:
         self.display_mode = DisplayMode.Shaded
         self.color_by = None
 
-    @property
+    @ property
     def fields_info(self) -> dict:
         return {} if not self.data else self.data[0]._fields
 
-    @property
+    @ property
     def active_field_info(self) -> DataFieldInfo:
         """Get information for active field info.
 
@@ -334,11 +496,11 @@ class ModelDataSet:
             self.data[count].add_data(
                 d, name=name, cell=per_face, colors=colors, data_range=data_range)
 
-    @property
+    @ property
     def is_empty(self):
         return len(self.data) == 0
 
-    @property
+    @ property
     def color(self) -> Color:
         """Diffuse color.
 
@@ -347,11 +509,11 @@ class ModelDataSet:
         """
         return self._color
 
-    @color.setter
+    @ color.setter
     def color(self, value: Color):
         self._color = value if value else Color(204, 204, 204, 255)
 
-    @property
+    @ property
     def color_by(self) -> str:
         """Set the field that the DataSet should colored-by when exported to vtkjs.
 
@@ -359,7 +521,7 @@ class ModelDataSet:
         """
         return self._color_by
 
-    @color_by.setter
+    @ color_by.setter
     def color_by(self, value: str):
         fields_info = self.fields_info
         if not value:
@@ -374,12 +536,12 @@ class ModelDataSet:
 
         self._color_by = value
 
-    @property
+    @ property
     def opacity(self) -> float:
         """Visualization opacity."""
         return self.color.a
 
-    @property
+    @ property
     def display_mode(self) -> DisplayMode:
         """Display model (AKA Representation) mode in VTK Glance viewer.
 
@@ -394,11 +556,11 @@ class ModelDataSet:
         """
         return self._display_mode
 
-    @display_mode.setter
+    @ display_mode.setter
     def display_mode(self, mode: DisplayMode = DisplayMode.Surface):
         self._display_mode = mode
 
-    @property
+    @ property
     def edge_visibility(self) -> bool:
         """Edge visibility.
 
@@ -433,9 +595,6 @@ class ModelDataSet:
             data = JoinedPolyData.from_polydata(self.data)
         return _write_to_folder(data, target_folder.as_posix())
 
-    # TODO: export color-range information for each dataset
-    # each dataset has its own information. If we can only have one then we should use
-    # the information for color_by field.
     def as_data_set(self, url=None) -> DataSet:
         """Convert to a vtkjs DataSet object.
 
@@ -458,11 +617,18 @@ class ModelDataSet:
         if self.color_by is not None:
             mapper.colorByArrayName = self.color_by
 
+        # Getting range of each data added to the ModelDataSet object.
+        ranges = {}
+        if self.name == 'Grid' and self.fields_info:
+            for name, value in self.fields_info.items():
+                ranges[name] = value.range
+
         data = {
             'name': self.name,
             'httpDataSetReader': {'url': url if url is not None else self.name},
             'property': ds_prop.dict(),
-            'mapper': mapper.dict()
+            'mapper': mapper.dict(),
+            'legend_ranges': ranges
         }
 
         return DataSet.parse_obj(data)
