@@ -1,6 +1,7 @@
 """Unit tests for the config module."""
 
 
+from honeybee_vtk.types import DataSetNames
 from _pytest.config import Config
 import pytest
 
@@ -11,25 +12,16 @@ from honeybee_vtk.scene import Scene
 from honeybee_vtk.camera import Camera
 from honeybee_vtk.actor import Actor
 from honeybee_vtk.config import Autocalculate, DataConfig, LegendConfig,\
-    _load_legend_parameters, load_config, TextConfig, DecimalCount, _validate_data,\
-    _load_data
+    _load_legend_parameters, load_config, TextConfig, DecimalCount, \
+    _validate_simulation_data, _load_data, _get_grid_type, _get_legend_range
 from honeybee_vtk.vtkjs.schema import DisplayMode, SensorGridOptions
 
-model_grid_mesh = r'tests/assets/gridbased.hbjson'
-
-valid_json_path = r'tests/assets/config/valid.json'
-range_json_path = r'tests/assets/config/range.json'
-invalid_json_path = r'tests/assets/config/invalid.json'
-more_grids = r'tests/assets/config/more_grids.json'
-identifier_mismatch = r'tests/assets/config/identifier_mismatch.json'
-short_length = r'tests/assets/config/short_length.json'
-
 
 def test_text_config_defaults():
     """Testting default settings of the TextConfig object."""
     text_config = TextConfig()
     assert text_config.color == [0, 0, 0]
-    assert text_config.size == 30
+    assert text_config.size == 0
     assert text_config.bold == False
 
 
@@ -145,7 +137,7 @@ def test_data_config_validators():
     """Testing if correct errors are being raised."""
 
     # all required fields missing
-    with pytest.raises(KeyError):
+    with pytest.raises(ValidationError):
         data_config = DataConfig()
 
     # required fields missing
@@ -156,13 +148,13 @@ def test_data_config_validators():
     with pytest.raises(ValidationError):
         data_config = DataConfig(
             identifier='Daylight-factor', object_type='grid', unit='Percentage',
-            folder_path='tests/assets/config/valid.json')
+            path='tests/assets/config/valid.json')
 
     # invalid object type
     with pytest.raises(ValidationError):
         data_config = DataConfig(
             identifier='Daylight-factor', object_type='ground', unit='Percentage',
-            folder_path='tests/assets/df_results')
+            path='tests/assets/df_results')
 
 
 def test_data_config_legend_parameter_validator():
@@ -175,7 +167,7 @@ def test_data_config_legend_parameter_validator():
     with pytest.raises(ValidationError):
         data_config = DataConfig(
             identifier='Daylight-factor', object_type='grid', unit='Percentage',
-            folder_path='tests/assets/df_results', legend_parameters=legend_params)
+            path='tests/assets/df_results', legend_parameters=legend_params)
 
     # height greater than position in Y direction
     legend_params = LegendConfig()
@@ -184,11 +176,13 @@ def test_data_config_legend_parameter_validator():
     with pytest.raises(ValidationError):
         data_config = DataConfig(
             identifier='Daylight-factor', object_type='grid', unit='Percentage',
-            folder_path='tests/assets/df_results', legend_parameters=legend_params)
+            path='tests/assets/df_results', legend_parameters=legend_params)
 
 
 def test_load_legend_parameter():
     """Testing load_legend_parameters function."""
+    model_grid_mesh = r'tests/assets/gridbased.hbjson'
+    valid_json_path = r'tests/assets/config/valid.json'
 
     model = Model.from_hbjson(model_grid_mesh, load_grids=SensorGridOptions.Mesh)
     cameras = model.cameras
@@ -199,50 +193,69 @@ def test_load_legend_parameter():
 
     # warning when loading data that is requested to be kept hidden
     with pytest.warns(Warning):
-        load_config(valid_json_path, model, scene)
-
-    # warning when loading data without min and max of legend specified
-    with pytest.warns(Warning):
-        load_config(range_json_path, model, scene)
-
-
-model = Model.from_hbjson(model_grid_mesh)
-scene = Scene()
+        load_config(valid_json_path, model, scene, validation=True, legend=True)
 
 
 def test_validate_data_invalid_json():
+    model_grid_mesh = r'tests/assets/gridbased.hbjson'
+    invalid_json_path = r'tests/assets/config/invalid.json'
+    model = Model.from_hbjson(model_grid_mesh)
+    scene = Scene()
     with pytest.raises(TypeError):
         load_config(invalid_json_path, model, scene)
 
 
 def test_validate_data_grids_not_loaded():
+    model_grid_mesh = r'tests/assets/gridbased.hbjson'
+    valid_json_path = r'tests/assets/config/valid.json'
+    model = Model.from_hbjson(model_grid_mesh)
+    scene = Scene()
     with pytest.raises(AssertionError):
         load_config(valid_json_path, model, scene)
 
 
-model_grids_loaded = Model.from_hbjson(
-    model_grid_mesh, load_grids=SensorGridOptions.Mesh)
-model_sensors_loaded = Model.from_hbjson(
-    model_grid_mesh, load_grids=SensorGridOptions.Sensors)
-
-scene_grids_loaded = Scene()
-cameras = model_grids_loaded.cameras
-actors = Actor.from_model(model_grids_loaded)
-scene_grids_loaded.add_cameras(cameras)
-scene_grids_loaded.add_actors(actors)
-
-
 def test_validate_data_number_of_grids_mismatch():
+    model_grid_mesh = r'tests/assets/gridbased.hbjson'
+    more_grids = r'tests/assets/config/more_grids.json'
+    model_grids_loaded = Model.from_hbjson(
+        model_grid_mesh, load_grids=SensorGridOptions.Mesh)
+    scene_grids_loaded = Scene()
+    cameras = model_grids_loaded.cameras
+    actors = Actor.from_model(model_grids_loaded)
+    scene_grids_loaded.add_cameras(cameras)
+    scene_grids_loaded.add_actors(actors)
+
     with pytest.raises(AssertionError):
-        load_config(more_grids, model_grids_loaded, scene_grids_loaded)
+        load_config(more_grids, model_grids_loaded, scene_grids_loaded, validation=True)
 
 
 def test_validate_data_identifier_mismatch():
+    model_grid_mesh = r'tests/assets/gridbased.hbjson'
+    identifier_mismatch = r'tests/assets/config/identifier_mismatch.json'
+    model_grids_loaded = Model.from_hbjson(
+        model_grid_mesh, load_grids=SensorGridOptions.Mesh)
+    scene_grids_loaded = Scene()
+    cameras = model_grids_loaded.cameras
+    actors = Actor.from_model(model_grids_loaded)
+    scene_grids_loaded.add_cameras(cameras)
+    scene_grids_loaded.add_actors(actors)
+
     with pytest.raises(AssertionError):
-        load_config(identifier_mismatch, model_grids_loaded, scene_grids_loaded)
+        load_config(identifier_mismatch, model_grids_loaded,
+                    scene_grids_loaded, validation=True)
 
 
 def test_validate_data_file_lengths_mismatch():
+    model_grid_mesh = r'tests/assets/gridbased.hbjson'
+    short_length = r'tests/assets/config/short_length.json'
+    model_grids_loaded = Model.from_hbjson(
+        model_grid_mesh, load_grids=SensorGridOptions.Mesh)
+    scene_grids_loaded = Scene()
+    cameras = model_grids_loaded.cameras
+    actors = Actor.from_model(model_grids_loaded)
+    scene_grids_loaded.add_cameras(cameras)
+    scene_grids_loaded.add_actors(actors)
+
     with pytest.raises(ValueError):
         load_config(short_length, model_grids_loaded, scene_grids_loaded)
 
@@ -250,19 +263,64 @@ def test_validate_data_file_lengths_mismatch():
 def test_grid_display_mode():
     """Test if correct dosplay mode is being selected for grids based on the type of
     grids in the model."""
+    model_grid_mesh = r'tests/assets/gridbased.hbjson'
+    valid_json_path = r'tests/assets/config/valid.json'
+    model_grids_loaded = Model.from_hbjson(
+        model_grid_mesh, load_grids=SensorGridOptions.Mesh)
+    scene_grids_loaded = Scene()
+    cameras = model_grids_loaded.cameras
+    actors = Actor.from_model(model_grids_loaded)
+    scene_grids_loaded.add_cameras(cameras)
+    scene_grids_loaded.add_actors(actors)
+
     model = load_config(valid_json_path, model_grids_loaded, scene_grids_loaded)
     assert model.sensor_grids.display_mode == DisplayMode.SurfaceWithEdges
 
+    model_sensors_loaded = Model.from_hbjson(
+        model_grid_mesh, load_grids=SensorGridOptions.Sensors)
+
     model = load_config(valid_json_path, model_sensors_loaded, scene_grids_loaded)
     assert model.sensor_grids.display_mode == DisplayMode.Points
 
 
-def grid_type():
-    """Test if validate_data returns correct grid type."""
+def test_get_grid_type():
+    """Test if _get_grid_type returns correct grid type."""
+    model_grid_mesh = r'tests/assets/gridbased.hbjson'
+    model_grids_loaded = Model.from_hbjson(
+        model_grid_mesh, load_grids=SensorGridOptions.Mesh)
+    assert _get_grid_type(model_grids_loaded) == 'meshes'
 
-    data = DataConfig()
-    assert _validate_data(data, model_grids_loaded) == 'meshes'
+    model_sensors_loaded = Model.from_hbjson(
+        model_grid_mesh, load_grids=SensorGridOptions.Sensors)
+    assert _get_grid_type(model_sensors_loaded) == 'points'
 
-    model_with_sensors_only = Model.from_hbjson(model_sensors_loaded,
-                                                load_grids=SensorGridOptions.Mesh)
-    assert _validate_data(data, model_with_sensors_only) == 'points'
+
+def test_get_legend_range():
+    """Test if the _get_legend_range supplies correct range."""
+    # if neither min nor max is set
+    lc = LegendConfig()
+    dc = DataConfig(identifier='test', object_type=DataSetNames.grid,
+                    unit='sample', path='.', legend_parameters=lc)
+    legend_range = _get_legend_range(dc)
+    assert legend_range == [None, None]
+
+    # if both min and max are set
+    lc = LegendConfig(min=0, max=0)
+    dc = DataConfig(identifier='test', object_type=DataSetNames.grid,
+                    unit='sample', path='.', legend_parameters=lc)
+    legend_range = _get_legend_range(dc)
+    assert legend_range == [0.0, 0.0]
+
+    # if only min is set
+    lc = LegendConfig(min=0)
+    dc = DataConfig(identifier='test', object_type=DataSetNames.grid,
+                    unit='sample', path='.', legend_parameters=lc)
+    legend_range = _get_legend_range(dc)
+    assert legend_range == [0.0, None]
+
+    # if only max is set
+    lc = LegendConfig(max=0)
+    dc = DataConfig(identifier='test', object_type=DataSetNames.grid,
+                    unit='sample', path='.', legend_parameters=lc)
+    legend_range = _get_legend_range(dc)
+    assert legend_range == [None, 0.0]
